searchData={"items":[{"type":"module","title":"LibOss","doc":"# LibOss\n\nLibOss是Elixir实现的一个[阿里云oss](https://help.aliyun.com/product/31815.html)的SDK，目前支持的功能有：\n\n- [ ] Object:\n  - [ ] 基础操作:\n    - [x] 上传文件\n    - [x] 获取文件\n    - [x] 删除文件\n    - [x] 删除多个文件\n    - [x] 获取前端直传签名\n    - [x] 文件在bucket间拷贝\n    - [x] 追加写文件\n    - [x] 获取文件元信息\n    - [ ] 通过HTML表单上传的方式将文件\n    - [ ] 归档解冻\n    - [ ] 执行SQL语句\n\n  - [x] 分片上传:\n    - [x] 分片上传发起\n    - [x] 分片上传完成\n    - [x] 分片上传取消\n    - [x] 分片上传列表\n    - [x] 列举指定uploadid已经成功上传的part\n\n  - [x] 权限控制ACL\n    - [x] 设置文件ACL\n    - [x] 获取文件ACL\n  - [x] 软连接\n    - [x] 创建软连接\n    - [x] 获取软连接\n  - [x] 标签\n    - [x] 设置标签\n    - [x] 获取标签\n    - [x] 删除标签\n \n- [ ] Bucket:\n  - [x] 基础操作:\n    - [x] 创建bucket\n    - [x] 删除bucket\n    - [x] 获取bucket中文件\n    - [x] 获取bucket中文件V2\n    - [x] 查看bucket的相关信息\n    - [x] 获取bucket存储容量以及文件（Object）数量\n    - [x] 查看bucket的位置信息\n\n  - [ ] 接入点\n    - [ ] 创建接入点\n    - [ ] 删除接入点\n    - [ ] 获取接入点\n    - [ ] 列举接入点\n    - [ ] 配置接入点策略配置\n    - [ ] 获取接入点策略配置\n    - [ ] 删除接入点策略配置\n\n  - [x] 权限控制\n    - [x] 设置bucket ACL\n    - [x] 获取bucket ACL\n\n  - [ ] 生命周期\n  - [ ] 传输加速\n  - [ ] 版本控制\n  - [ ] 数据复制\n  - [ ] 授权策略\n  - [ ] 清单\n  - [ ] 日志管理\n  - [ ] 静态网站\n  - [ ] 防盗链\n  - [ ] 标签\n  - [ ] 加密\n  - [ ] 请求者付费\n  - [ ] 访问跟踪\n  - [ ] 数据索引\n  - [ ] 高防\n  - [ ] 资源组\n  - [ ] 自定义域名\n  - [ ] 图片样式\n  - [ ] 归档直读\n\n- [ ] LiveChannel","ref":"LibOss.html"},{"type":"module","title":"使用方法 - LibOss","doc":"```elixir\nMix.install([\n  {:lib_oss, \"~> 0.1.0\"}\n])\n\n# 创建一个oss客户端\ncli =\n  LibOss.new(\n    endpoint: \"oss-cn-somewhere.aliyuncs.com\",\n    access_key_id: \"your access key id\",\n    access_key_secret: \"your access key secret\"\n  )\n\n# 在superivsor中启动\nSupervisor.start_link(\n  [\n    {LibOss, client: cli}\n  ],\n  strategy: :one_for_one\n)\n\n# 上传文件\n{:ok, content} = File.read(\"./test.txt\")\nLibOss.put_object(cli, \"hope-data\", \"/test/test.txt\", content)\n```\n\n更多使用方法请参考[API文档](https://hexdocs.pm/lib_oss/LibOss.html)","ref":"LibOss.html#module-%E4%BD%BF%E7%94%A8%E6%96%B9%E6%B3%95"},{"type":"function","title":"LibOss.abort_multipart_upload/4","doc":"AbortMultipartUpload接口用于取消MultipartUpload事件并删除对应的Part数据。\n\nDoc: https://help.aliyun.com/document_detail/31996.html","ref":"LibOss.html#abort_multipart_upload/4"},{"type":"function","title":"Examples - LibOss.abort_multipart_upload/4","doc":"{:ok, return_value} = function_name()","ref":"LibOss.html#abort_multipart_upload/4-examples"},{"type":"function","title":"LibOss.append_object/6","doc":"调用AppendObject接口用于以追加写的方式上传文件（Object）。\n\nDoc: https://help.aliyun.com/document_detail/31981.html","ref":"LibOss.html#append_object/6"},{"type":"function","title":"Examples - LibOss.append_object/6","doc":"iex> LibOss.append_object(cli, bucket, \"/test/test.txt\", 0, \"hello \")\n    iex> LibOss.append_object(cli, bucket, \"/test/test.txt\", 6, \"world\")","ref":"LibOss.html#append_object/6-examples"},{"type":"function","title":"LibOss.child_spec/1","doc":"","ref":"LibOss.html#child_spec/1"},{"type":"function","title":"LibOss.complete_multipart_upload/6","doc":"所有数据Part都上传完成后，您必须调用CompleteMultipartUpload接口来完成整个文件的分片上传。\n\nDoc: https://help.aliyun.com/document_detail/31995.html","ref":"LibOss.html#complete_multipart_upload/6"},{"type":"function","title":"Examples - LibOss.complete_multipart_upload/6","doc":"iex> {:ok, etag1} = upload_part(client, bucket, \"test.txt\", \"upload_id\", 1, part1)\n    iex> {:ok, etag2} = upload_part(client, bucket, \"test.txt\", \"upload_id\", 2, part2)\n    iex> {:ok, etag3} = upload_part(client, bucket, \"test.txt\", \"upload_id\", 3, part3)\n    iex> complete_multipart_upload(client, bucket, \"test.txt\", \"upload_id\", [{1, etag1}, {2, etag2}, {3, etag3}])\n    {:ok, _}","ref":"LibOss.html#complete_multipart_upload/6-examples"},{"type":"function","title":"LibOss.copy_object/6","doc":"调用CopyObject接口拷贝同一地域下相同或不同存储空间（Bucket）之间的文件（Object）。\n\nDoc: https://help.aliyun.com/document_detail/31979.html","ref":"LibOss.html#copy_object/6"},{"type":"function","title":"Examples - LibOss.copy_object/6","doc":"LibOss.copy_object(cli, target_bucket, \"object_copy.txt\", source_bucket, \"object.txt\")","ref":"LibOss.html#copy_object/6-examples"},{"type":"function","title":"LibOss.delete_bucket/2","doc":"调用DeleteBucket删除某个存储空间（Bucket）。\n\nDoc: https://help.aliyun.com/document_detail/31973.html","ref":"LibOss.html#delete_bucket/2"},{"type":"function","title":"Examples - LibOss.delete_bucket/2","doc":"{:ok, _} = LibOss.delete_bucket(cli, to-delete-bucket)","ref":"LibOss.html#delete_bucket/2-examples"},{"type":"function","title":"LibOss.delete_multiple_objects/3","doc":"DeleteMultipleObjects接口用于删除同一个存储空间（Bucket）中的多个文件（Object）。\n\nDoc: https://help.aliyun.com/document_detail/31983.html","ref":"LibOss.html#delete_multiple_objects/3"},{"type":"function","title":"Examples - LibOss.delete_multiple_objects/3","doc":"LibOss.delete_multiple_objects(cli, bucket, [\"/test/test_1.txt\", \"/test/test_2.txt\"]])","ref":"LibOss.html#delete_multiple_objects/3-examples"},{"type":"function","title":"LibOss.delete_object/3","doc":"调用DeleteObject删除某个文件（Object）。\n\nDoc: https://help.aliyun.com/document_detail/31982.html","ref":"LibOss.html#delete_object/3"},{"type":"function","title":"Examples - LibOss.delete_object/3","doc":"{:ok, _} = LibOss.delete_object(cli, bucket, \"/test/test.txt\")","ref":"LibOss.html#delete_object/3-examples"},{"type":"function","title":"LibOss.delete_object_tagging/3","doc":"删除Object当前版本的标签信息。\n\nDoc: https://help.aliyun.com/document_detail/114879.html","ref":"LibOss.html#delete_object_tagging/3"},{"type":"function","title":"Examples - LibOss.delete_object_tagging/3","doc":"iex> LibOss.delete_object_tagging(cli, bucket, \"/test/test.txt\")","ref":"LibOss.html#delete_object_tagging/3-examples"},{"type":"function","title":"LibOss.get_bucket/3","doc":"GetBucket (ListObjects)接口用于列举存储空间（Bucket）中所有文件（Object）的信息。\n\nDoc: https://help.aliyun.com/document_detail/31965.html\n\n其中query_params具体细节参考上面链接中`请求参数`部分","ref":"LibOss.html#get_bucket/3"},{"type":"function","title":"Examples - LibOss.get_bucket/3","doc":"iex> LibOss.get_bucket(cli, bucket, %{\"prefix\" => \"test/test\"})\n    {:ok, [\n      %{\n       \"ETag\" => \"\"A5D2B2E40EF7EBA1C788697D31C27A78-3\"\",\n       \"Key\" => \"test/test.txt\",\n       \"LastModified\" => \"2023-07-09T14:41:08.000Z\",\n       \"Owner\" => %{\n         \"DisplayName\" => \"1074124462684153\",\n         \"ID\" => \"1074124462684153\"\n       },\n       \"Size\" => \"409608\",\n       \"StorageClass\" => \"Standard\",\n       \"Type\" => \"Multipart\"\n     },\n     %{\n       \"ETag\" => \"\"5EB63BBBE01EEED093CB22BB8F5ACDC3\"\",\n       \"Key\" => \"test/test_1.txt\",\n       \"LastModified\" => \"2023-07-09T14:41:08.000Z\",\n       \"Owner\" => %{\n         \"DisplayName\" => \"1074124462684153\",\n         \"ID\" => \"1074124462684153\"\n       },\n       \"Size\" => \"11\",\n       \"StorageClass\" => \"Standard\",\n       \"Type\" => \"Normal\"\n     }\n    ]}","ref":"LibOss.html#get_bucket/3-examples"},{"type":"function","title":"LibOss.get_bucket_acl/2","doc":"GetBucketAcl接口用于获取某个存储空间（Bucket）的访问权限（ACL）。\n\nDoc: https://help.aliyun.com/document_detail/31966.html","ref":"LibOss.html#get_bucket_acl/2"},{"type":"function","title":"Examples - LibOss.get_bucket_acl/2","doc":"iex> LibOss.get_bucket_acl(cli, bucket)\n    {:ok,\n    %{\n       \"AccessControlList\" => %{\"Grant\" => \"public-read\"},\n       \"Owner\" => %{\"DisplayName\" => \"107412446268415\", \"ID\" => \"107412446264153\"}\n     }}","ref":"LibOss.html#get_bucket_acl/2-examples"},{"type":"function","title":"LibOss.get_bucket_info/2","doc":"调用GetBucketInfo接口查看存储空间（Bucket）的相关信息。\n\nDoc: https://help.aliyun.com/document_detail/31968.html","ref":"LibOss.html#get_bucket_info/2"},{"type":"function","title":"Examples - LibOss.get_bucket_info/2","doc":"iex> LibOss.get_bucket_info(cli, bucket)\n    {:ok,\n     %{\n       \"Bucket\" => %{\n         \"AccessControlList\" => %{\"Grant\" => \"public-read\"},\n         \"AccessMonitor\" => \"Disabled\",\n         \"BucketPolicy\" => %{\"LogBucket\" => nil, \"LogPrefix\" => nil},\n         \"Comment\" => nil,\n         \"CreationDate\" => \"2022-08-02T14:59:56.000Z\",\n         \"CrossRegionReplication\" => \"Disabled\",\n         \"DataRedundancyType\" => \"LRS\",\n         \"ExtranetEndpoint\" => \"oss-cn-shenzhen.aliyuncs.com\",\n         \"IntranetEndpoint\" => \"oss-cn-shenzhen-internal.aliyuncs.com\",\n         \"Location\" => \"oss-cn-shenzhen\",\n         \"Name\" => \"xxxx-data\",\n         \"Owner\" => %{\n           \"DisplayName\" => \"1074124462684153\",\n           \"ID\" => \"1074124462684153\"\n         },\n         \"ResourceGroupId\" => \"rg-acfmv47nudzpp6i\",\n         \"ServerSideEncryptionRule\" => %{\"SSEAlgorithm\" => \"None\"},\n         \"StorageClass\" => \"Standard\",\n         \"TransferAcceleration\" => \"Enabled\"\n       }\n     }}","ref":"LibOss.html#get_bucket_info/2-examples"},{"type":"function","title":"LibOss.get_bucket_location/2","doc":"GetBucketLocation接口用于查看存储空间（Bucket）的位置信息。\n\nDoc: https://help.aliyun.com/document_detail/31967.html","ref":"LibOss.html#get_bucket_location/2"},{"type":"function","title":"Examples - LibOss.get_bucket_location/2","doc":"iex> LibOss.get_bucket_location(cli, bucket)\n    {:ok, \"oss-cn-shenzhen\"}","ref":"LibOss.html#get_bucket_location/2-examples"},{"type":"function","title":"LibOss.get_bucket_stat/2","doc":"调用GetBucketStat接口获取指定存储空间（Bucket）的存储容量以及文件（Object）数量。\n\nDoc: https://help.aliyun.com/document_detail/426056.html","ref":"LibOss.html#get_bucket_stat/2"},{"type":"function","title":"Examples - LibOss.get_bucket_stat/2","doc":"iex> LibOss.get_bucket_stat(cli, bucket)\n    {:ok, {:ok,\n     %{\n       \"ArchiveObjectCount\" => \"0\",\n       \"ArchiveRealStorage\" => \"0\",\n       \"ArchiveStorage\" => \"0\",\n       \"ColdArchiveObjectCount\" => \"0\",\n       \"ColdArchiveRealStorage\" => \"0\",\n       \"ColdArchiveStorage\" => \"0\",\n       \"DeepColdArchiveObjectCount\" => \"0\",\n       \"DeepColdArchiveRealStorage\" => \"0\",\n       \"DeepColdArchiveStorage\" => \"0\",\n       \"DeleteMarkerCount\" => \"0\",\n       \"InfrequentAccessObjectCount\" => \"0\",\n       \"InfrequentAccessRealStorage\" => \"0\",\n       \"InfrequentAccessStorage\" => \"0\",\n       \"LastModifiedTime\" => \"1690118142\",\n       \"LiveChannelCount\" => \"0\",\n       \"MultipartPartCount\" => \"59\",\n       \"MultipartUploadCount\" => \"30\",\n       \"ObjectCount\" => \"5413\",\n       \"ReservedCapacityObjectCount\" => \"0\",\n       \"ReservedCapacityStorage\" => \"0\",\n       \"StandardObjectCount\" => \"5413\",\n       \"StandardStorage\" => \"9619258561\",\n       \"Storage\" => \"9619258561\"\n     }}","ref":"LibOss.html#get_bucket_stat/2-examples"},{"type":"function","title":"LibOss.get_object/4","doc":"GetObject接口用于获取某个文件（Object）。此操作需要对此Object具有读权限。\n\nDoc: https://help.aliyun.com/document_detail/31980.html\n\nreq_headers的具体参数可参考文档中”请求头“部分说明","ref":"LibOss.html#get_object/4"},{"type":"function","title":"Examples - LibOss.get_object/4","doc":"LibOss.get_object(cli, bucket, \"/test/test.txt\")","ref":"LibOss.html#get_object/4-examples"},{"type":"function","title":"LibOss.get_object_acl/3","doc":"调用GetObjectACL接口获取存储空间（Bucket）下某个文件（Object）的访问权限（ACL）。\n\nDoc: https://help.aliyun.com/document_detail/31987.html","ref":"LibOss.html#get_object_acl/3"},{"type":"function","title":"Examples - LibOss.get_object_acl/3","doc":"iex> LibOss.get_object_acl(cli, bucket, \"/test/test.txt\")\n    {:ok, \"public-read\"}","ref":"LibOss.html#get_object_acl/3-examples"},{"type":"function","title":"LibOss.get_object_meta/3","doc":"调用GetObjectMeta接口获取一个文件（Object）的元数据信息，包括该Object的ETag、Size、LastModified信息，并且不返回该Object的内容。\n\nDoc: https://help.aliyun.com/document_detail/31985.html","ref":"LibOss.html#get_object_meta/3"},{"type":"function","title":"Examples - LibOss.get_object_meta/3","doc":"iex> LibOss.get_object_meta(cli, bucket, \"/test/test.txt\")\n    {:ok,\n     %{\n       \"accept-ranges\" => \"bytes\",\n       \"connection\" => \"keep-alive\",\n       \"content-length\" => \"11\",\n       \"content-md5\" => \"XrY7u+Ae7tCTyyK7j1rNww==\",\n       \"content-type\" => \"text/plain\",\n       \"date\" => \"Tue, 18 Jul 2023 06:29:10 GMT\",\n       \"etag\" => \"\"5EB63BBBE01EEED093CB22BB8F5ACDC3\"\",\n       \"last-modified\" => \"Tue, 18 Jul 2023 06:27:33 GMT\",\n       \"server\" => \"AliyunOSS\",\n       \"x-oss-hash-crc64ecma\" => \"5981764153023615706\",\n       \"x-oss-object-type\" => \"Normal\",\n       \"x-oss-request-id\" => \"64B631365A8AEE32306C9D64\",\n       \"x-oss-server-time\" => \"2\",\n       \"x-oss-storage-class\" => \"Standard\"\n     }}","ref":"LibOss.html#get_object_meta/3-examples"},{"type":"function","title":"LibOss.get_object_tagging/3","doc":"调用GetObjectTagging接口获取对象（Object）的标签（Tagging）信息。\n\nDoc: https://help.aliyun.com/document_detail/114878.html","ref":"LibOss.html#get_object_tagging/3"},{"type":"function","title":"Examples - LibOss.get_object_tagging/3","doc":"iex> LibOss.get_object_tagging(cli, bucket, \"/test/test.txt\")\n    {:ok,\n     [\n       %{\"Key\" => \"key1\", \"Value\" => \"value1\"},\n       %{\"Key\" => \"key2\", \"Value\" => \"value2\"}\n     ]}","ref":"LibOss.html#get_object_tagging/3-examples"},{"type":"function","title":"LibOss.get_symlink/3","doc":"调用GetSymlink接口获取软链接。\n\nDoc: https://help.aliyun.com/document_detail/45146.html","ref":"LibOss.html#get_symlink/3"},{"type":"function","title":"Examples - LibOss.get_symlink/3","doc":"iex> LibOss.get_symlink(cli, bucket, \"/test/test.txt\")\n    {:ok, \"/test/test_symlink.txt\"}","ref":"LibOss.html#get_symlink/3-examples"},{"type":"function","title":"LibOss.get_token/5","doc":"function description\n通过Web端直传文件（Object）到OSS的签名生成\n\nDoc: https://help.aliyun.com/document_detail/31926.html","ref":"LibOss.html#get_token/5"},{"type":"function","title":"Example - LibOss.get_token/5","doc":"iex> LibOss.get_token(cli, bucket, \"/test/test.txt\")\n    {:ok, \"{\"accessid\":\"LTAI1k8kxWG8JpUF\",\"callback\":\"=\",\"dir\":\"/test/test.txt\",\".........ePNPyWQo=\"}\"}","ref":"LibOss.html#get_token/5-example"},{"type":"function","title":"LibOss.head_object/4","doc":"HeadObject接口用于获取某个文件（Object）的元信息。使用此接口不会返回文件内容。\n\nDoc: https://help.aliyun.com/document_detail/31984.html","ref":"LibOss.html#head_object/4"},{"type":"function","title":"Examples - LibOss.head_object/4","doc":"iex> LibOss.head_object(cli, bucket, \"/test/test.txt\")\n    {:ok,\n     %{\n       \"accept-ranges\" => \"bytes\",\n       \"connection\" => \"keep-alive\",\n       \"content-length\" => \"11\",\n       \"content-md5\" => \"XrY7u+Ae7tCTyyK7j1rNww==\",\n       \"content-type\" => \"text/plain\",\n       \"date\" => \"Tue, 18 Jul 2023 06:27:36 GMT\",\n       \"etag\" => \"\"5EB63BBBE01EEED093CB22BB8F5ACDC3\"\",\n       \"last-modified\" => \"Tue, 18 Jul 2023 06:27:33 GMT\",\n       \"server\" => \"AliyunOSS\",\n       \"x-oss-hash-crc64ecma\" => \"5981764153023615706\",\n       \"x-oss-object-type\" => \"Normal\",\n       \"x-oss-request-id\" => \"64B630D8E0DCB93335001974\",\n       \"x-oss-server-time\" => \"1\",\n       \"x-oss-storage-class\" => \"Standard\"\n     }}","ref":"LibOss.html#head_object/4-examples"},{"type":"function","title":"LibOss.init_multi_upload/4","doc":"使用Multipart Upload模式传输数据前，您必须先调用InitiateMultipartUpload接口来通知OSS初始化一个Multipart Upload事件。\n\nDoc: https://help.aliyun.com/document_detail/31992.html","ref":"LibOss.html#init_multi_upload/4"},{"type":"function","title":"Examples - LibOss.init_multi_upload/4","doc":"iex> init_multi_uploads(client, bucket, \"test.txt\")\n    {:ok, \"upload_id\"}","ref":"LibOss.html#init_multi_upload/4-examples"},{"type":"function","title":"LibOss.list_multipart_uploads/3","doc":"调用ListMultipartUploads接口列举所有执行中的Multipart Upload事件，即已经初始化但还未完成（Complete）或者还未中止（Abort）的Multipart Upload事件。\n\nDoc: https://help.aliyun.com/document_detail/31997.html","ref":"LibOss.html#list_multipart_uploads/3"},{"type":"function","title":"Examples - LibOss.list_multipart_uploads/3","doc":"iex> list_multipart_uploads(client, bucket, %{\"delimiter\"=>\"/\", \"max-uploads\" => 10, \"prefix\"=>\"test/\"})\n    {:ok,\n     [\n       %{\n         \"ETag\" => \"\"1334928900AEB317206CC7EB950540EF-3\"\",\n         \"Key\" => \"test/multi-test.txt\",\n         \"LastModified\" => \"2023-07-18T11:16:45.000Z\",\n         \"Owner\" => %{\n           \"DisplayName\" => \"1074124462684153\",\n           \"ID\" => \"1074124462684153\"\n         },\n         \"Size\" => \"409608\",\n         \"StorageClass\" => \"Standard\",\n         \"Type\" => \"Multipart\"\n       },\n       %{\n         \"ETag\" => \"\"5EB63BBBE01EEED093CB22BB8F5ACDC3\"\",\n         \"Key\" => \"test/test.txt\",\n         \"LastModified\" => \"2023-07-18T11:19:19.000Z\",\n         \"Owner\" => %{\n           \"DisplayName\" => \"1074124462684153\",\n           \"ID\" => \"1074124462684153\"\n         },\n         \"Size\" => \"11\",\n         \"StorageClass\" => \"Standard\",\n         \"Type\" => \"Normal\"\n       }\n     ]}","ref":"LibOss.html#list_multipart_uploads/3-examples"},{"type":"function","title":"LibOss.list_object_v2/3","doc":"ListObjectsV2（GetBucketV2）接口用于列举存储空间（Bucket）中所有文件（Object）的信息。\n\nDoc: https://help.aliyun.com/document_detail/187544.html","ref":"LibOss.html#list_object_v2/3"},{"type":"function","title":"Examples - LibOss.list_object_v2/3","doc":"iex> LibOss.list_object_v2(cli, bucket, %{\"prefix\" => \"test/test\"})\n    {:ok,\n     [\n       %{\n         \"ETag\" => \"\"A5D2B2E40EF7EBA1C788697D31C27A78-3\"\",\n         \"Key\" => \"test/test.txt\",\n         \"LastModified\" => \"2023-07-09T14:41:08.000Z\",\n         \"Owner\" => %{\n           \"DisplayName\" => \"1074124462684153\",\n           \"ID\" => \"1074124462684153\"\n         },\n         \"Size\" => \"409608\",\n         \"StorageClass\" => \"Standard\",\n         \"Type\" => \"Multipart\"\n       },\n       %{\n         \"ETag\" => \"\"5EB63BBBE01EEED093CB22BB8F5ACDC3\"\",\n         \"Key\" => \"test/test_1.txt\",\n         \"LastModified\" => \"2023-07-09T14:41:08.000Z\",\n         \"Owner\" => %{\n           \"DisplayName\" => \"1074124462684153\",\n           \"ID\" => \"1074124462684153\"\n         },\n         \"Size\" => \"11\",\n         \"StorageClass\" => \"Standard\",\n         \"Type\" => \"Normal\"\n       }\n     ]}","ref":"LibOss.html#list_object_v2/3-examples"},{"type":"function","title":"LibOss.list_parts/5","doc":"ListParts接口用于列举指定Upload ID所属的所有已经上传成功Part。\n\nDoc: https://help.aliyun.com/document_detail/31998.html","ref":"LibOss.html#list_parts/5"},{"type":"function","title":"Examples - LibOss.list_parts/5","doc":"{:ok, return_value} = function_name()\n    iex> LibOss.list_parts(cli, bucket, \"test.txt\", \"upload_id\")\n    {:ok,\n     %{\n      \"ListPartsResult\" => %{\n        \"Bucket\" => \"hope-data\",\n        \"IsTruncated\" => \"false\",\n        \"Key\" => \"test/multi-test.txt\",\n        \"MaxParts\" => \"1000\",\n        \"NextPartNumberMarker\" => \"3\",\n        \"Part\" => [\n          %{\n            \"ETag\" => \"\"3170FC594DACE56C506E0196B5DEA1D1\"\",\n            \"HashCrc64ecma\" => \"10873275732915280589\",\n            \"LastModified\" => \"2023-07-19T02:58:16.000Z\",\n            \"PartNumber\" => \"1\",\n            \"Size\" => \"136536\"\n          },\n          %{\n            \"ETag\" => \"\"5539D60A05FD504B8210A662D7D15C1E\"\",\n            \"HashCrc64ecma\" => \"4592881501542342075\",\n            \"LastModified\" => \"2023-07-19T02:58:17.000Z\",\n            \"PartNumber\" => \"2\",\n            \"Size\" => \"136536\"\n          },\n          %{\n            \"ETag\" => \"\"5C7D509F5744115EE3B2D55F4893FE3F\"\",\n            \"HashCrc64ecma\" => \"9048307046109329978\",\n            \"LastModified\" => \"2023-07-19T02:58:17.000Z\",\n            \"PartNumber\" => \"3\",\n            \"Size\" => \"136536\"\n          }\n        ],\n        \"PartNumberMarker\" => \"0\",\n        \"StorageClass\" => \"Standard\",\n        \"UploadId\" => \"39663F02E9384C87BFC9E9B0E8B1100E\"\n      }\n    }}","ref":"LibOss.html#list_parts/5-examples"},{"type":"function","title":"LibOss.new/1","doc":"create a new oss client instance","ref":"LibOss.html#new/1"},{"type":"function","title":"Params - LibOss.new/1","doc":"* `:name` (`t:atom/0`) - LibOss name The default value is `LibOss`.\n\n* `:access_key_id` (`t:String.t/0`) - Required. OSS access key id\n\n* `:access_key_secret` (`t:String.t/0`) - Required. OSS access key secret\n\n* `:endpoint` (`t:String.t/0`) - Required. OSS endpoint\n\n* `:http_impl` (`t:term/0`) - HTTP client implementation of `LibOss.Http` The default value is `%LibOss.Http.Default{name: LibOss.Http.Default}`.","ref":"LibOss.html#new/1-params"},{"type":"function","title":"Examples - LibOss.new/1","doc":"LibOss.new(\n      endpoint: \"oss-cn-hangzhou.aliyuncs.com\",\n      access_key_id: \"access_key_id\",\n      access_key_secret: \"access_key_secret\"\n    )","ref":"LibOss.html#new/1-examples"},{"type":"function","title":"LibOss.put_bucket/5","doc":"调用PutBucket接口创建存储空间（Bucket）。\n\nDoc: https://help.aliyun.com/document_detail/31959.html","ref":"LibOss.html#put_bucket/5"},{"type":"function","title":"Examples - LibOss.put_bucket/5","doc":"{:ok, _} = LibOss.put_bucket(cli, your-new-bucket)","ref":"LibOss.html#put_bucket/5-examples"},{"type":"function","title":"LibOss.put_bucket_acl/3","doc":"PutBucketAcl接口用于设置或修改存储空间（Bucket）的访问权限（ACL）。\n\nDoc: https://help.aliyun.com/document_detail/31960.html","ref":"LibOss.html#put_bucket_acl/3"},{"type":"function","title":"Examples - LibOss.put_bucket_acl/3","doc":"iex> LibOss.put_bucket_acl(cli, bucket, \"public-read\")","ref":"LibOss.html#put_bucket_acl/3-examples"},{"type":"function","title":"LibOss.put_object/5","doc":"调用PutObject接口上传文件（Object）。\n\nDoc: https://help.aliyun.com/document_detail/31978.html","ref":"LibOss.html#put_object/5"},{"type":"function","title":"Examples - LibOss.put_object/5","doc":"LibOss.put_object(cli, bucket, \"/test/test.txt\", \"hello world\")","ref":"LibOss.html#put_object/5-examples"},{"type":"function","title":"LibOss.put_object_acl/4","doc":"调用PutObjectACL接口修改文件（Object）的访问权限（ACL）\n\nDoc: https://help.aliyun.com/document_detail/31986.html","ref":"LibOss.html#put_object_acl/4"},{"type":"function","title":"Examples - LibOss.put_object_acl/4","doc":"iex> LibOss.put_object_acl(cli, bucket, \"/test/test.txt\", \"public-read\")","ref":"LibOss.html#put_object_acl/4-examples"},{"type":"function","title":"LibOss.put_object_tagging/4","doc":"调用PutObjectTagging接口设置或更新对象（Object）的标签（Tagging）信息。\n\nDoc: https://help.aliyun.com/document_detail/114855.html","ref":"LibOss.html#put_object_tagging/4"},{"type":"function","title":"Examples - LibOss.put_object_tagging/4","doc":"iex> LibOss.put_object_tagging(cli, bucket, \"/test/test.txt\", %{\"key1\" => \"value1\", \"key2\" => \"value2\"})","ref":"LibOss.html#put_object_tagging/4-examples"},{"type":"function","title":"LibOss.put_symlink/5","doc":"调用PutSymlink接口用于为OSS的目标文件（TargetObject）创建软链接（Symlink）\n\nDoc: https://help.aliyun.com/document_detail/45126.html","ref":"LibOss.html#put_symlink/5"},{"type":"function","title":"Examples - LibOss.put_symlink/5","doc":"iex> LibOss.put_symlink(cli, bucket, \"/test/test.txt\", \"/test/test_symlink.txt\")","ref":"LibOss.html#put_symlink/5-examples"},{"type":"function","title":"LibOss.start_link/1","doc":"","ref":"LibOss.html#start_link/1"},{"type":"function","title":"LibOss.upload_part/6","doc":"初始化一个MultipartUpload后，调用UploadPart接口根据指定的Object名和uploadId来分块（Part）上传数据。\n\nDoc: https://help.aliyun.com/document_detail/31993.html","ref":"LibOss.html#upload_part/6"},{"type":"function","title":"Examples - LibOss.upload_part/6","doc":"iex> upload_part(client, bucket, \"test.txt\", \"upload_id\", 1, \"hello world\")\n    {:ok, \"etag\"}","ref":"LibOss.html#upload_part/6-examples"},{"type":"type","title":"LibOss.lib_oss_opts_t/0","doc":"","ref":"LibOss.html#t:lib_oss_opts_t/0"},{"type":"type","title":"LibOss.t/0","doc":"","ref":"LibOss.html#t:t/0"},{"type":"behaviour","title":"LibOss.Http","doc":"behavior os http transport","ref":"LibOss.Http.html"},{"type":"function","title":"LibOss.Http.do_request/2","doc":"","ref":"LibOss.Http.html#do_request/2"},{"type":"callback","title":"LibOss.Http.do_request/2","doc":"","ref":"LibOss.Http.html#c:do_request/2"},{"type":"callback","title":"LibOss.Http.new/1","doc":"","ref":"LibOss.Http.html#c:new/1"},{"type":"function","title":"LibOss.Http.start_link/1","doc":"","ref":"LibOss.Http.html#start_link/1"},{"type":"callback","title":"LibOss.Http.start_link/1","doc":"","ref":"LibOss.Http.html#c:start_link/1"},{"type":"type","title":"LibOss.Http.t/0","doc":"","ref":"LibOss.Http.html#t:t/0"},{"type":"module","title":"LibOss.Http.Default","doc":"Implement LibOss.Http behavior with Finch","ref":"LibOss.Http.Default.html"},{"type":"function","title":"LibOss.Http.Default.child_spec/1","doc":"","ref":"LibOss.Http.Default.html#child_spec/1"},{"type":"type","title":"LibOss.Http.Default.t/0","doc":"","ref":"LibOss.Http.Default.html#t:t/0"},{"type":"module","title":"LibOss.Http.Request","doc":"http request","ref":"LibOss.Http.Request.html"},{"type":"function","title":"LibOss.Http.Request.new/1","doc":"create new http request instance","ref":"LibOss.Http.Request.html#new/1"},{"type":"function","title":"Params - LibOss.Http.Request.new/1","doc":"* `:scheme` (`t:String.t/0`) - http scheme The default value is `\"https\"`.\n\n* `:host` (`t:String.t/0`) - Required. http host\n\n* `:port` (`t:integer/0`) - http port The default value is `443`.\n\n* `:method` (`t:term/0`) - http method The default value is `:get`.\n\n* `:path` (`t:String.t/0`) - http path The default value is `\"/\"`.\n\n* `:headers` (list of `t:term/0`) - http headers The default value is `[]`.\n\n* `:body` (`t:term/0`) - http body The default value is `nil`.\n\n* `:params` (map of `t:String.t/0` keys and `t:String.t/0` values) - http query params The default value is `%{}`.\n\n* `:opts` (`t:keyword/0`) - http opts The default value is `[]`.","ref":"LibOss.Http.Request.html#new/1-params"},{"type":"function","title":"LibOss.Http.Request.url/1","doc":"","ref":"LibOss.Http.Request.html#url/1"},{"type":"type","title":"LibOss.Http.Request.http_request_schema_t/0","doc":"","ref":"LibOss.Http.Request.html#t:http_request_schema_t/0"},{"type":"type","title":"LibOss.Http.Request.t/0","doc":"","ref":"LibOss.Http.Request.html#t:t/0"},{"type":"module","title":"LibOss.Http.Response","doc":"http response","ref":"LibOss.Http.Response.html"},{"type":"function","title":"LibOss.Http.Response.new/1","doc":"","ref":"LibOss.Http.Response.html#new/1"},{"type":"type","title":"LibOss.Http.Response.http_response_schema_t/0","doc":"","ref":"LibOss.Http.Response.html#t:http_response_schema_t/0"},{"type":"type","title":"LibOss.Http.Response.t/0","doc":"","ref":"LibOss.Http.Response.html#t:t/0"},{"type":"module","title":"LibOss.Request","doc":"request struct","ref":"LibOss.Request.html"},{"type":"function","title":"LibOss.Request.auth/2","doc":"","ref":"LibOss.Request.html#auth/2"},{"type":"function","title":"LibOss.Request.build_headers/2","doc":"","ref":"LibOss.Request.html#build_headers/2"},{"type":"function","title":"LibOss.Request.new/1","doc":"create a new request struct","ref":"LibOss.Request.html#new/1"},{"type":"function","title":"Options - LibOss.Request.new/1","doc":"* `:host` (`t:String.t/0`) - OSS host The default value is `\"\"`.\n\n* `:method` - Required. HTTP method\n\n* `:object` (`t:String.t/0`) - OSS object The default value is `\"\"`.\n\n* `:resource` (`t:String.t/0`) - OSS resource The default value is `\"/\"`.\n\n* `:sub_resources` (list of `t:term/0`) - OSS sub resources The default value is `[]`.\n\n* `:bucket` (`t:String.t/0`) - Required. OSS bucket\n\n* `:params` (map of `t:String.t/0` keys and `t:String.t/0` values) - OSS query params The default value is `%{}`.\n\n* `:body` (`t:String.t/0`) - HTTP body The default value is `\"\"`.\n\n* `:headers` (list of `t:term/0`) - HTTP headers The default value is `[]`.\n\n* `:expires` (`t:integer/0`) - oss expires The default value is `0`.\n\n* `:debug` (`t:boolean/0`) - debug The default value is `false`.","ref":"LibOss.Request.html#new/1-options"},{"type":"type","title":"LibOss.Request.request_schema_t/0","doc":"","ref":"LibOss.Request.html#t:request_schema_t/0"},{"type":"type","title":"LibOss.Request.t/0","doc":"","ref":"LibOss.Request.html#t:t/0"},{"type":"module","title":"LibOss.Typespecs","doc":"some typespecs","ref":"LibOss.Typespecs.html"},{"type":"type","title":"LibOss.Typespecs.access_point_name/0","doc":"","ref":"LibOss.Typespecs.html#t:access_point_name/0"},{"type":"type","title":"LibOss.Typespecs.acl/0","doc":"","ref":"LibOss.Typespecs.html#t:acl/0"},{"type":"type","title":"LibOss.Typespecs.body/0","doc":"","ref":"LibOss.Typespecs.html#t:body/0"},{"type":"type","title":"LibOss.Typespecs.bucket/0","doc":"","ref":"LibOss.Typespecs.html#t:bucket/0"},{"type":"type","title":"LibOss.Typespecs.headers/0","doc":"","ref":"LibOss.Typespecs.html#t:headers/0"},{"type":"type","title":"LibOss.Typespecs.host/0","doc":"","ref":"LibOss.Typespecs.html#t:host/0"},{"type":"type","title":"LibOss.Typespecs.http_status/0","doc":"","ref":"LibOss.Typespecs.html#t:http_status/0"},{"type":"type","title":"LibOss.Typespecs.method/0","doc":"","ref":"LibOss.Typespecs.html#t:method/0"},{"type":"type","title":"LibOss.Typespecs.object/0","doc":"","ref":"LibOss.Typespecs.html#t:object/0"},{"type":"type","title":"LibOss.Typespecs.on_start/0","doc":"","ref":"LibOss.Typespecs.html#t:on_start/0"},{"type":"type","title":"LibOss.Typespecs.opts/0","doc":"","ref":"LibOss.Typespecs.html#t:opts/0"},{"type":"type","title":"LibOss.Typespecs.params/0","doc":"","ref":"LibOss.Typespecs.html#t:params/0"},{"type":"type","title":"LibOss.Typespecs.string_dict/0","doc":"","ref":"LibOss.Typespecs.html#t:string_dict/0"},{"type":"module","title":"LibOss.Utils","doc":"utils","ref":"LibOss.Utils.html"},{"type":"function","title":"LibOss.Utils.debug/1","doc":"","ref":"LibOss.Utils.html#debug/1"},{"type":"function","title":"LibOss.Utils.do_sign/2","doc":"","ref":"LibOss.Utils.html#do_sign/2"},{"type":"exception","title":"LibOss.Error","doc":"error of lib_oss","ref":"LibOss.Error.html"},{"type":"function","title":"LibOss.Error.new/1","doc":"","ref":"LibOss.Error.html#new/1"},{"type":"type","title":"LibOss.Error.t/0","doc":"","ref":"LibOss.Error.html#t:t/0"}],"content_type":"text/markdown"}